package de.survivalprojekt.LS.Managers;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;
import java.nio.file.StandardCopyOption;
import java.util.Set;
import java.util.UUID;

import org.bukkit.Bukkit;
import org.bukkit.OfflinePlayer;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.entity.Player;

import de.survivalprojekt.LS.ServerManager;

public class WhitelistManager {
    private File whitelistFile;
    private FileConfiguration whitelistConfig;
    private boolean whitelistEnabled = true; // Standardmäßig aktiviert

    public WhitelistManager() {
        initFile();
    }

    private void initFile() {
        ServerManager inst = ServerManager.getInst();
        /////// SETUP CONFIG ///////
        whitelistFile = new File(inst.getDataFolder(), "whitelist.yml");
        if (!whitelistFile.exists()) {
            try (InputStream inputStream = inst.getResource("whitelist.yml")) {
                if (inputStream != null) {
                    Files.copy(inputStream, whitelistFile.toPath(), StandardCopyOption.REPLACE_EXISTING);
                    inst.getLogger().info("Die Standard-Whitelist-Konfigurationsdatei wurde erstellt.");
                } else {
                    inst.getLogger().warning("Standard Whitelist-Konfigurationsdatei konnte nicht gefunden werden.");
                }
            } catch (IOException e) {
                inst.getLogger().severe("Fehler beim erstellen der Whitelist-Konfigurationsdatei: " + e.getMessage());
            }
        }
        whitelistConfig = YamlConfiguration.loadConfiguration(whitelistFile);
        ///// GIBT KEINEN GRUND JEDEN SCHEISS ZU LOGGEN /////
        /// DAFÜR GIBT ES FUCKING ERROR MESSAGES /////
        inst.getLogger().info("Whitelist-Konfiguration wurde <neu> geladen.");
    }

    public void reload() {
        initFile();
    }

    public void save() {
        ServerManager inst = ServerManager.getInst();
        try {
            whitelistConfig.save(whitelistFile);
        } catch (IOException e) {
            inst.getLogger().info("Fehler beim Speichern der Whitelist: " + e.getMessage());
        }
    }

    public boolean addPlayer(String name) {
        ServerManager inst = ServerManager.getInst();
        OfflinePlayer pl = Bukkit.getOfflinePlayer(name);
        UUID id = null;
        String rname = null;
        if (pl != null) {
            rname = pl.getName();
            id = pl.getUniqueId();
        }
        if (id == null || rname == null || rname.isEmpty()) {
            inst.getLogger().info("Spieler " + name + " konnte nicht gefunden werden!");
            return false;
        }
        if (whitelistConfig.getConfigurationSection("whitelist") == null) {
            whitelistConfig.createSection("whitelist");
        }
        whitelistConfig.set("whitelist." + id.toString() + ".name", rname);
        save();
        inst.getLogger().info("Spieler " + rname + "wurde zur Whitelist hinzugefügt");
        return true;
    }

    public boolean removePlayer(String name) {
        ServerManager inst = ServerManager.getInst();
        if (whitelistConfig.getConfigurationSection("whitelist") != null) {
            for (String uuid : whitelistConfig.getConfigurationSection("whitelist").getKeys(false)) {
                String lname = whitelistConfig.getString("whitelist." + uuid + ".name");
                if (lname != null && lname.equalsIgnoreCase(name)) {
                    whitelistConfig.set("whitelist." + uuid, null);
                    save();
                    inst.getLogger().info("Spieler " + lname + " wurde von der Whitelist entfernt.");
                    return true;
                }
            }
        }
        inst.getLogger().info("Spieler " + name + " ist nicht auf der Whitelist.");
        return false;
    }

    public Set<String> getWhitelistedPlayers() {
        if (whitelistConfig.getConfigurationSection("whitelist") == null) {
            return null;
        }
        return whitelistConfig.getConfigurationSection("whitelist").getKeys(false);
    }

    public String getWhitelistedPlayerName(String uuid) {
        return whitelistConfig.getString("whitelist." + uuid + ".name");
    }

    public boolean isWhitelisted(UUID uuid) {
        return whitelistConfig.getConfigurationSection("whitelist") != null &&
                whitelistConfig.getConfigurationSection("whitelist").contains(uuid.toString());
    }

    public String getMessage() {
        return whitelistConfig.getString("message");
    }

    public boolean getWhitelistEnabled() {
        return this.whitelistEnabled;
    }

    public void setWhitelistEnabled(boolean value) {
        this.whitelistEnabled = value;
    }
}
