package de.survivalprojekt.LS;

import org.bukkit.Bukkit;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.PluginCommand;
import org.bukkit.command.TabCompleter;
import org.bukkit.plugin.java.JavaPlugin;

import de.survivalprojekt.LS.Commands.MotdCommand;
import de.survivalprojekt.LS.Commands.WartungsCommand;
import de.survivalprojekt.LS.Commands.WhitelistCommand;
import de.survivalprojekt.LS.Listeners.PlayerListener;
import de.survivalprojekt.LS.Listeners.ServerListListener;
import de.survivalprojekt.LS.Managers.MotdManager;
import de.survivalprojekt.LS.Managers.WartungsManager;
import de.survivalprojekt.LS.Managers.WhitelistManager;
import de.survivalprojekt.LS.TabCompleters.MotdCompleter;
import de.survivalprojekt.LS.TabCompleters.WartungsCompleter;
import de.survivalprojekt.LS.TabCompleters.WhitelistCompleter;

/// Default CMD to Override
/// whitelist

public class ServerManager extends JavaPlugin {
    static ServerManager inst;

    MotdManager motdManager;
    WartungsManager wartungsManager;
    WhitelistManager whitelistManager;

    @Override
    public void onLoad() {
        inst = this;
    }

    @Override
    public void onEnable() {
        // Setup Data Folder
        if (!getDataFolder().exists()) {
            getDataFolder().mkdirs();
        }
        // Create Managers
        motdManager = new MotdManager();
        wartungsManager = new WartungsManager();
        whitelistManager = new WhitelistManager();
        // Declare Events
        Bukkit.getPluginManager().registerEvents(new ServerListListener(), inst);
        Bukkit.getPluginManager().registerEvents(new PlayerListener(), inst);

        // Declare Commands [not the ovrride one]
        setUpCommand("motd", new MotdCommand(), new MotdCompleter());
        setUpCommand("wartung", new WartungsCommand(), new WartungsCompleter());
        setUpCommand("whitelist", new WhitelistCommand(), new WhitelistCompleter());
    }

    private void setUpCommand(final String command, CommandExecutor exec, TabCompleter tc) {
        PluginCommand cmd = getCommand(command);
        if (cmd != null) {
            cmd.setExecutor(exec);
            if (tc != null) {
                cmd.setTabCompleter(tc);
            }
        } else {
            getLogger().info("Error: Command " + command + " nicht gefunden!");
        }
    }

    public static ServerManager getInst() {
        return inst;
    }

    public MotdManager getMotdManager() {
        return motdManager;
    }

    public WartungsManager getWartungsManager() {
        return this.wartungsManager;
    }

    public WhitelistManager getWhitelistManager() {
      return this.whitelistManager;
    }
}
